tests.factories.pipeline package — django_analyses 0.0.3 documentation

# tests.factories.pipeline package

## Submodules

## tests.factories.pipeline.node module

class `tests.factories.pipeline.node.` `NodeFactory`

  Bases: `factory.django.DjangoModelFactory`

  `analysis_version` = <factory.declarations.SubFactory object>
  `created` = <factory.faker.Faker object>
  `modified` = <factory.faker.Faker object>

## tests.factories.pipeline.pipe module

class `tests.factories.pipeline.pipe.` `PipeFactory`

  Bases: `factory.django.DjangoModelFactory`

  `base_destination_port` = <factory.declarations.SubFactory object>
  `base_source_port` = <factory.declarations.SubFactory object>
  `destination` = <factory.declarations.SubFactory object>
  `pipeline` = <factory.declarations.SubFactory object>
  `source` = <factory.declarations.SubFactory object>

## tests.factories.pipeline.pipeline module

class `tests.factories.pipeline.pipeline.` `PipelineFactory`

  Bases: `factory.django.DjangoModelFactory`

  `created` = <factory.faker.Faker object>
  `description` = <factory.faker.Faker object>
  `modified` = <factory.faker.Faker object>
  `title` = <factory.faker.Faker object>

## Module contents